@@ -4,7 +4,7 @@ extract_parameter_set_dials.recipe <- function(x, ...) {
   tuning_param <- generics::tune_args(x)
   res <-
     dplyr::inner_join(
-      tuning_param %>% dplyr::select(-tunable),
+      tuning_param |> dplyr::select(-tunable),
       all_args,
       by = c("name", "source", "component", "component_id")
     )
