@@ -5,33 +5,32 @@
 #'
 #' @inheritParams step_pca
 #' @inheritParams step_center
-#' @param options A list of options to
-#'  [fastICA::fastICA()]. No defaults are set here.
+#' @param options A list of options to [fastICA::fastICA()]. No defaults are set
+#'   here.
 #'  **Note** that the arguments `X` and `n.comp` should
-#'  not be passed here.
-#' @param seed A single integer to set the random number stream prior to
-#'  running ICA.
-#' @param res The [fastICA::fastICA()] object is stored
-#'  here once this preprocessing step has be trained by
-#'  [prep()].
+#'   not be passed here.
+#' @param seed A single integer to set the random number stream prior to running
+#'   ICA.
+#' @param res The [fastICA::fastICA()] object is stored here once this
+#'   preprocessing step has be trained by [prep()].
 #' @template step-return
 #' @family multivariate transformation steps
 #' @export
-#' @details Independent component analysis (ICA) is a
-#'  transformation of a group of variables that produces a new set
-#'  of artificial features or components. ICA assumes that the
-#'  variables are mixtures of a set of distinct, non-Gaussian
-#'  signals and attempts to transform the data to isolate these
-#'  signals. Like PCA, the components are statistically independent
-#'  from one another. This means that they can be used to combat
-#'  large inter-variables correlations in a data set. Also like PCA,
-#'  it is advisable to center and scale the variables prior to
-#'  running ICA.
+#' @details
 #'
-#' This package produces components using the "FastICA"
-#'  methodology (see reference below). This step requires the
-#'  \pkg{dimRed} and \pkg{fastICA} packages. If not installed, the
-#'  step will stop with a note about installing these packages.
+#' Independent component analysis (ICA) is a transformation of a group of
+#' variables that produces a new set of artificial features or components. ICA
+#' assumes that the variables are mixtures of a set of distinct, non-Gaussian
+#' signals and attempts to transform the data to isolate these signals. Like
+#' PCA, the components are statistically independent from one another. This
+#' means that they can be used to combat large inter-variables correlations in a
+#' data set. Also like PCA, it is advisable to center and scale the variables
+#' prior to running ICA.
+#'
+#' This package produces components using the "FastICA" methodology (see
+#' reference below). This step requires the \pkg{dimRed} and \pkg{fastICA}
+#' packages. If not installed, the step will stop with a note about installing
+#' these packages.
 #'
 #' ```{r, echo = FALSE, results="asis"}
 #' prefix <- "IC"
@@ -161,6 +160,7 @@ prep.step_ica <- function(x, training, info = NULL, ...) {
   col_names <- recipes_eval_select(x$terms, training, info)
   check_type(training[, col_names], types = c("double", "integer"))
   check_string(x$prefix, arg = "prefix")
+  check_options(x$options, exclude = c("X", "n.comp"))
 
   if (x$num_comp > 0 && length(col_names) > 0) {
     x$num_comp <- min(x$num_comp, length(col_names))
@@ -173,16 +173,8 @@ prep.step_ica <- function(x, training, info = NULL, ...) {
         X = rlang::expr(as.matrix(training[, col_names]))
       )
     cl <- rlang::call_modify(cl, !!!x$options)
-    indc <- try(withr::with_seed(x$seed, rlang::eval_tidy(cl)), silent = TRUE)
 
-    if (inherits(indc, "try-error")) {
-      cli::cli_abort(
-        c(
-          x = "Failed with error:",
-          i = as.character(indc)
-        )
-      )
-    }
+    indc <- try_fetch_eval_tidy(withr::with_seed(x$seed, rlang::eval_tidy(cl)))
 
     indc <- indc[c("K", "W")]
     indc$means <- colMeans(training[, col_names])
