@@ -77,20 +77,20 @@
 #' data(biomass, package = "modeldata")
 #'
 #' biom_tr <-
-#'   biomass %>%
-#'   dplyr::filter(dataset == "Training") %>%
+#'   biomass |>
+#'   dplyr::filter(dataset == "Training") |>
 #'   dplyr::select(-dataset, -sample)
 #' biom_te <-
-#'   biomass %>%
-#'   dplyr::filter(dataset == "Testing") %>%
+#'   biomass |>
+#'   dplyr::filter(dataset == "Testing") |>
 #'   dplyr::select(-dataset, -sample, -HHV)
 #'
 #' dense_pls <-
-#'   recipe(HHV ~ ., data = biom_tr) %>%
+#'   recipe(HHV ~ ., data = biom_tr) |>
 #'   step_pls(all_numeric_predictors(), outcome = HHV, num_comp = 3)
 #'
 #' sparse_pls <-
-#'   recipe(HHV ~ ., data = biom_tr) %>%
+#'   recipe(HHV ~ ., data = biom_tr) |>
 #'   step_pls(all_numeric_predictors(), outcome = HHV, num_comp = 3,
 #'            predictor_prop = 4 / 5)
 #'
@@ -100,20 +100,20 @@
 #' data(cells, package = "modeldata")
 #'
 #' cell_tr <-
-#'   cells %>%
-#'   dplyr::filter(case == "Train") %>%
+#'   cells |>
+#'   dplyr::filter(case == "Train") |>
 #'   dplyr::select(-case)
 #' cell_te <-
-#'   cells %>%
-#'   dplyr::filter(case == "Test") %>%
+#'   cells |>
+#'   dplyr::filter(case == "Test") |>
 #'   dplyr::select(-case, -class)
 #'
 #' dense_plsda <-
-#'   recipe(class ~ ., data = cell_tr) %>%
+#'   recipe(class ~ ., data = cell_tr) |>
 #'   step_pls(all_numeric_predictors(), outcome = class, num_comp = 5)
 #'
 #' sparse_plsda <-
-#'   recipe(class ~ ., data = cell_tr) %>%
+#'   recipe(class ~ ., data = cell_tr) |>
 #'   step_pls(all_numeric_predictors(), outcome = class, num_comp = 5,
 #'            predictor_prop = 1 / 4)
 step_pls <-
@@ -321,7 +321,7 @@ pls_project <- function(object, x) {
   z <- sweep(z, 2, STATS = object$sd, "/")
   res <- z %*% object$coefs
   res <- tibble::as_tibble(res)
-  res <- purrr::map2_dfc(res, object$col_norms, ~.x * .y)
+  res <- purrr::map2_dfc(res, object$col_norms, \(.x, .y) .x * .y)
   res
 }
 
@@ -471,14 +471,14 @@ tidy.step_pls <- function(x, ...) {
         purrr::map2_dfc(
           as.data.frame(x$res$coefs),
           x$res$col_norms,
-          ~.x * .y
-        ) %>%
-          dplyr::mutate(terms = rownames(x$res$coefs)) %>%
-          tidyr::pivot_longer(
-            c(-terms),
-            names_to = "component",
-            values_to = "value"
-          )
+          ~ .x * .y
+        ) |>
+        dplyr::mutate(terms = rownames(x$res$coefs)) |>
+        tidyr::pivot_longer(
+          c(-terms),
+          names_to = "component",
+          values_to = "value"
+        )
       res <- res[, c("terms", "value", "component")]
       res$component <- gsub("comp", "PLS", res$component)
     } else {
