@@ -1,4 +1,3 @@
-
 #' @importFrom generics tidy
 #' @export
 generics::tidy
@@ -23,6 +22,22 @@ hardhat::extract_parameter_set_dials
 #' @export
 hardhat::extract_parameter_dials
 
+#' @importFrom hardhat importance_weights
+#' @export
+hardhat::importance_weights
+
+#' @importFrom hardhat frequency_weights
+#' @export
+hardhat::frequency_weights
+
 #' @importFrom magrittr %>%
 #' @export
 magrittr::`%>%`
+
+#' @importFrom hardhat extract_fit_time
+#' @export
+hardhat::extract_fit_time
+
+#' @importFrom stats update
+#' @export
+stats::update
