@@ -295,28 +295,28 @@ recipes_eval_select <- function(
 #' @examplesIf rlang::is_installed("modeldata")
 #' data(biomass, package = "modeldata")
 #'
-#' rec <- recipe(biomass) %>%
+#' rec <- recipe(biomass) |>
 #'   update_role(
 #'     carbon, hydrogen, oxygen, nitrogen, sulfur,
 #'     new_role = "predictor"
-#'   ) %>%
-#'   update_role(HHV, new_role = "outcome") %>%
-#'   update_role(sample, new_role = "id variable") %>%
+#'   ) |>
+#'   update_role(HHV, new_role = "outcome") |>
+#'   update_role(sample, new_role = "id variable") |>
 #'   update_role(dataset, new_role = "splitting indicator")
 #'
 #' recipe_info <- summary(rec)
 #' recipe_info
 #'
 #' # Centering on all predictors except carbon
-#' rec %>%
-#'   step_center(all_predictors(), -carbon) %>%
-#'   prep(training = biomass) %>%
+#' rec |>
+#'   step_center(all_predictors(), -carbon) |>
+#'   prep(training = biomass) |>
 #'   bake(new_data = NULL)
 #' @export
 has_role <- function(match = "predictor") {
   roles <- peek_roles()
   # roles is potentially a list columns so we unlist `.x` below.
-  lgl_matches <- purrr::map_lgl(roles, ~any(unlist(.x) %in% match))
+  lgl_matches <- purrr::map_lgl(roles, \(.x) any(unlist(.x) %in% match))
   which(lgl_matches)
 }
 
@@ -324,7 +324,7 @@ has_role <- function(match = "predictor") {
 #' @rdname has_role
 has_type <- function(match = "numeric") {
   types <- peek_types()
-  lgl_matches <- purrr::map_lgl(types, ~any(.x %in% match))
+  lgl_matches <- purrr::map_lgl(types, \(.x) any(.x %in% match))
   which(lgl_matches)
 }
 
@@ -338,7 +338,7 @@ peek_types <- function() {
 
 peek_info <- function(col) {
   .data <- current_info()$data
-  purrr::map(.data, ~unlist(.x[[col]]))
+  purrr::map(.data, \(.x) unlist(.x[[col]]))
 }
 
 #' @export
