@@ -9,26 +9,26 @@ iris_rec <- recipe(~., data = iris)
 
 test_that("basic usage", {
   rec <-
-    iris_rec %>%
-      step_arrange(desc(Sepal.Length), 1 / Petal.Length)
+    iris_rec |>
+    step_arrange(desc(Sepal.Length), 1 / Petal.Length)
 
-  prepped <- prep(rec, training = iris %>% slice(1:75))
+  prepped <- prep(rec, training = iris |> slice(1:75))
 
   dplyr_train <-
-    iris %>%
-      as_tibble() %>%
-      slice(1:75) %>%
-      dplyr::arrange(desc(Sepal.Length), 1 / Petal.Length)
+    iris |>
+    as_tibble() |>
+    slice(1:75) |>
+    dplyr::arrange(desc(Sepal.Length), 1 / Petal.Length)
 
   rec_train <- bake(prepped, new_data = NULL)
   expect_equal(dplyr_train, rec_train)
 
   dplyr_test <-
-    iris %>%
-      as_tibble() %>%
-      slice(76:150) %>%
-      dplyr::arrange(desc(Sepal.Length), 1 / Petal.Length)
-  rec_test <- bake(prepped, iris %>% slice(76:150))
+    iris |>
+    as_tibble() |>
+    slice(76:150) |>
+    dplyr::arrange(desc(Sepal.Length), 1 / Petal.Length)
+  rec_test <- bake(prepped, iris |> slice(76:150))
   expect_equal(dplyr_test, rec_test)
 })
 
@@ -36,16 +36,16 @@ test_that("quasiquotation", {
   sort_vars <- c("Sepal.Length", "Petal.Length")
   sort_vars <- syms(sort_vars)
   rec_1 <-
-    iris_rec %>%
-      step_arrange(!!!sort_vars)
+    iris_rec |>
+    step_arrange(!!!sort_vars)
 
-  prepped_1 <- prep(rec_1, training = iris %>% slice(1:75))
+  prepped_1 <- prep(rec_1, training = iris |> slice(1:75))
 
   dplyr_train <-
-    iris %>%
-      as_tibble() %>%
-      slice(1:75) %>%
-      arrange(Sepal.Length, Petal.Length)
+    iris |>
+    as_tibble() |>
+    slice(1:75) |>
+    arrange(Sepal.Length, Petal.Length)
 
   rec_1_train <- bake(prepped_1, new_data = NULL)
   expect_equal(dplyr_train, rec_1_train)
@@ -53,10 +53,10 @@ test_that("quasiquotation", {
 
 test_that("no input", {
   no_inputs <-
-    iris_rec %>%
-      step_arrange() %>%
-      prep(training = iris) %>%
-      bake(new_data = NULL, composition = "data.frame")
+    iris_rec |>
+    step_arrange() |>
+    prep(training = iris) |>
+    bake(new_data = NULL, composition = "data.frame")
   expect_equal(no_inputs, iris)
 })
 
@@ -64,8 +64,8 @@ test_that("doesn't destroy sparsity", {
   mtcars$vs <- sparsevctrs::as_sparse_integer(mtcars$vs)
   mtcars$am <- sparsevctrs::as_sparse_integer(mtcars$am)
 
-  rec <- recipe(~., mtcars) %>%
-    step_arrange(vs) %>%
+  rec <- recipe(~., mtcars) |>
+    step_arrange(vs) |>
     prep()
 
   expect_true(.recipes_preserve_sparsity(rec$steps[[1]]))
@@ -120,7 +120,7 @@ test_that("empty selection tidy method works", {
 })
 
 test_that("printing", {
-  rec <- iris_rec %>%
+  rec <- iris_rec |>
     step_arrange(Sepal.Length)
 
   expect_snapshot(print(rec))
@@ -129,8 +129,8 @@ test_that("printing", {
 
 test_that("0 and 1 rows data work in bake method", {
   data <- iris
-  rec <- recipe(~., data = data) %>%
-    step_arrange(Sepal.Length) %>%
+  rec <- recipe(~., data = data) |>
+    step_arrange(Sepal.Length) |>
     prep()
 
   expect_identical(
