@@ -13,7 +13,7 @@ rec <- recipe(
 )
 
 test_that("correct basis functions", {
-  with_bs <- rec %>%
+  with_bs <- rec |>
     step_bs(carbon, hydrogen, deg_free = 5, degree = 2)
 
   with_bs <- prep(with_bs, training = biomass_tr, verbose = FALSE)
@@ -80,16 +80,16 @@ test_that("correct basis functions", {
 test_that("options(knots) works correctly (#1297)", {
   exmaple_data <- tibble(x = seq(-2, 2, 0.01))
 
-  rec_res <- recipe(~., data = exmaple_data) %>%
+  rec_res <- recipe(~., data = exmaple_data) |>
     step_bs(
       x,
       options = list(knots = seq(-1, 1, 0.125), Boundary.knots = c(-2.5, 2.5))
-    ) %>%
-    prep() %>%
+    ) |>
+    prep() |>
     bake(new_data = NULL)
 
   mm_res <- model.matrix(
-    ~splines::bs(
+    ~ splines::bs(
       x,
       knots = seq(-1, 1, 0.125),
       Boundary.knots = c(-2.5, 2.5)
@@ -108,7 +108,7 @@ test_that("check_name() is used", {
   dat <- mtcars
   dat$mpg_bs_1 <- dat$mpg
 
-  rec <- recipe(~., data = dat) %>%
+  rec <- recipe(~., data = dat) |>
     step_bs(mpg)
 
   expect_snapshot(
@@ -119,8 +119,8 @@ test_that("check_name() is used", {
 
 test_that("tunable", {
   rec <-
-    recipe(~., data = iris) %>%
-      step_bs(all_predictors())
+    recipe(~., data = iris) |>
+    step_bs(all_predictors())
   rec_param <- tunable.step_bs(rec$steps[[1]])
   expect_equal(rec_param$name, c("deg_free", "degree"))
   expect_true(all(rec_param$source == "recipe"))
@@ -133,8 +133,8 @@ test_that("tunable", {
 })
 
 test_that("works when baked with 1 row", {
-  rec <- recipe(mpg ~ ., data = mtcars) %>%
-    step_bs(disp) %>%
+  rec <- recipe(mpg ~ ., data = mtcars) |>
+    step_bs(disp) |>
     prep()
 
   expect_no_error(
@@ -147,8 +147,8 @@ test_that("works when baked with 1 row", {
 test_that("check_options() is used", {
   expect_snapshot(
     error = TRUE,
-    recipe(mpg ~ ., data = mtcars) %>%
-      step_bs(disp, options = TRUE) %>%
+    recipe(mpg ~ ., data = mtcars) |>
+      step_bs(disp, options = TRUE) |>
       prep()
   )
 })
@@ -156,9 +156,9 @@ test_that("check_options() is used", {
 # Infrastructure ---------------------------------------------------------------
 
 test_that("bake method errors when needed non-standard role columns are missing", {
-  with_bs <- rec %>%
-    step_bs(carbon, hydrogen, deg_free = 5, degree = 2) %>%
-    update_role(carbon, hydrogen, new_role = "potato") %>%
+  with_bs <- rec |>
+    step_bs(carbon, hydrogen, deg_free = 5, degree = 2) |>
+    update_role(carbon, hydrogen, new_role = "potato") |>
     update_role_requirements(role = "potato", bake = FALSE)
 
   with_bs <- prep(with_bs, training = biomass_tr, verbose = FALSE)
@@ -206,7 +206,7 @@ test_that("empty selection tidy method works", {
 test_that("keep_original_cols works", {
   new_names <- c("mpg_bs_1", "mpg_bs_2", "mpg_bs_3")
 
-  rec <- recipe(~mpg, mtcars) %>%
+  rec <- recipe(~mpg, mtcars) |>
     step_bs(all_predictors(), keep_original_cols = FALSE)
 
   rec <- prep(rec)
@@ -217,7 +217,7 @@ test_that("keep_original_cols works", {
     new_names
   )
 
-  rec <- recipe(~mpg, mtcars) %>%
+  rec <- recipe(~mpg, mtcars) |>
     step_bs(all_predictors(), keep_original_cols = TRUE)
 
   rec <- prep(rec)
@@ -230,7 +230,7 @@ test_that("keep_original_cols works", {
 })
 
 test_that("keep_original_cols - can prep recipes with it missing", {
-  rec <- recipe(~mpg, mtcars) %>%
+  rec <- recipe(~mpg, mtcars) |>
     step_bs(all_predictors())
 
   rec$steps[[1]]$keep_original_cols <- NULL
@@ -245,7 +245,7 @@ test_that("keep_original_cols - can prep recipes with it missing", {
 })
 
 test_that("printing", {
-  with_bs <- rec %>%
+  with_bs <- rec |>
     step_bs(carbon, hydrogen)
 
   expect_snapshot(print(with_bs))
@@ -254,7 +254,7 @@ test_that("printing", {
 
 test_that("tunable is setup to work with extract_parameter_set_dials", {
   skip_if_not_installed("dials")
-  rec <- recipe(~., data = mtcars) %>%
+  rec <- recipe(~., data = mtcars) |>
     step_bs(
       all_predictors(),
       deg_free = hardhat::tune(),
@@ -269,8 +269,8 @@ test_that("tunable is setup to work with extract_parameter_set_dials", {
 
 test_that("0 and 1 rows data work in bake method", {
   data <- mtcars
-  rec <- recipe(~., data) %>%
-    step_bs(mpg, disp) %>%
+  rec <- recipe(~., data) |>
+    step_bs(mpg, disp) |>
     prep()
 
   expect_identical(
