@@ -6,16 +6,16 @@ data(covers, package = "modeldata")
 covers$rows <- 1:nrow(covers)
 covers$ch_rows <- paste(1:nrow(covers))
 
-rec <- recipe(~description + rows + ch_rows, covers)
+rec <- recipe(~ description + rows + ch_rows, covers)
 
 counts <- gregexpr(pattern = "(rock|stony)", text = covers$description)
 counts <- vapply(counts, function(x) length(x[x > 0]), integer(1))
 chars <- nchar(covers$description)
 
 test_that("default options", {
-  rec1 <- rec %>%
-    step_count(description, pattern = "(rock|stony)") %>%
-    step_count(description, pattern = "", result = "every thing") %>%
+  rec1 <- rec |>
+    step_count(description, pattern = "(rock|stony)") |>
+    step_count(description, pattern = "", result = "every thing") |>
     step_count(
       description,
       pattern = "(rock|stony)",
@@ -34,7 +34,7 @@ test_that("default options", {
 })
 
 test_that("nondefault options", {
-  rec2 <- rec %>%
+  rec2 <- rec |>
     step_count(
       description,
       pattern = "(rock|stony)",
@@ -49,16 +49,16 @@ test_that("nondefault options", {
 test_that("bad selector(s)", {
   expect_snapshot(
     error = TRUE,
-    rec %>% step_count(description, rows, pattern = "(rock|stony)")
+    rec |> step_count(description, rows, pattern = "(rock|stony)")
   )
-  rec2 <- rec %>% step_count(rows, pattern = "(rock|stony)")
+  rec2 <- rec |> step_count(rows, pattern = "(rock|stony)")
   expect_snapshot(error = TRUE, prep(rec2, training = covers))
 })
 
 test_that("check_name() is used", {
   dat <- iris
 
-  rec <- recipe(~., data = dat) %>%
+  rec <- recipe(~., data = dat) |>
     step_count(Species, result = "Sepal.Width")
 
   expect_snapshot(
@@ -70,7 +70,7 @@ test_that("check_name() is used", {
 test_that("checks for grepl arguments", {
   expect_snapshot(
     error = TRUE,
-    recipe(~., data = mtcars) %>%
+    recipe(~., data = mtcars) |>
       step_count(options = list(not_real_option = TRUE))
   )
 })
@@ -79,23 +79,23 @@ test_that("sparse = 'yes' works", {
   rec <- recipe(~description, covers)
 
   suppressWarnings({
-    dense <- rec %>%
+    dense <- rec |>
       step_count(
         description,
         pattern = "stony",
         sparse = "no",
         keep_original_cols = FALSE
-      ) %>%
-      prep() %>%
+      ) |>
+      prep() |>
       bake(NULL)
-    sparse <- rec %>%
+    sparse <- rec |>
       step_count(
         description,
         pattern = "stony",
         sparse = "yes",
         keep_original_cols = FALSE
-      ) %>%
-      prep() %>%
+      ) |>
+      prep() |>
       bake(NULL)
   })
 
@@ -106,8 +106,8 @@ test_that("sparse = 'yes' works", {
 })
 
 test_that("sparse argument is backwards compatible", {
-  rec <- recipe(~description, covers) %>%
-    step_count(description, pattern = "stony") %>%
+  rec <- recipe(~description, covers) |>
+    step_count(description, pattern = "stony") |>
     prep()
 
   exp <- bake(rec, covers)
@@ -122,10 +122,10 @@ test_that("sparse argument is backwards compatible", {
 })
 
 test_that(".recipes_toggle_sparse_args works", {
-  rec <- recipe(~description, covers) %>%
+  rec <- recipe(~description, covers) |>
     step_count(description, pattern = "stony", sparse = "auto")
 
-  exp <- rec %>% prep() %>% bake(NULL) %>% sparsevctrs::sparsity()
+  exp <- rec |> prep() |> bake(NULL) |> sparsevctrs::sparsity()
 
   expect_true(
     .recipes_estimate_sparsity(rec) > exp
@@ -135,8 +135,8 @@ test_that(".recipes_toggle_sparse_args works", {
 test_that("check_options() is used", {
   expect_snapshot(
     error = TRUE,
-    recipe(~description, data = covers) %>%
-      step_count(description, options = TRUE) %>%
+    recipe(~description, data = covers) |>
+      step_count(description, options = TRUE) |>
       prep()
   )
 })
@@ -144,15 +144,13 @@ test_that("check_options() is used", {
 # Infrastructure ---------------------------------------------------------------
 
 test_that("bake method errors when needed non-standard role columns are missing", {
-  mt_tibble <- mtcars %>%
+  mt_tibble <- mtcars |>
     tibble::rownames_to_column(var = "make_model")
 
-  rec <-
-    mt_tibble %>%
-      recipe(mpg ~ ., data = .) %>%
-      step_count(make_model, pattern = "Toyota", result = "is_toyota") %>%
-      update_role(make_model, new_role = "potato") %>%
-      update_role_requirements(role = "potato", bake = FALSE)
+  rec <- recipe(mpg ~ ., data = mt_tibble) |>
+    step_count(make_model, pattern = "Toyota", result = "is_toyota") |>
+    update_role(make_model, new_role = "potato") |>
+    update_role_requirements(role = "potato", bake = FALSE)
 
   rec_trained <- prep(rec, training = mt_tibble)
 
@@ -202,7 +200,7 @@ test_that("empty selection tidy method works", {
 test_that("keep_original_cols works", {
   new_names <- c("rocks")
 
-  rec <- recipe(~description, covers) %>%
+  rec <- recipe(~description, covers) |>
     step_count(
       description,
       pattern = "(rock|stony)",
@@ -218,7 +216,7 @@ test_that("keep_original_cols works", {
     new_names
   )
 
-  rec <- recipe(~description, covers) %>%
+  rec <- recipe(~description, covers) |>
     step_count(
       description,
       pattern = "(rock|stony)",
@@ -236,7 +234,7 @@ test_that("keep_original_cols works", {
 })
 
 test_that("keep_original_cols - can prep recipes with it missing", {
-  rec <- recipe(~description, covers) %>%
+  rec <- recipe(~description, covers) |>
     step_count(
       description,
       pattern = "(rock|stony)",
@@ -256,7 +254,7 @@ test_that("keep_original_cols - can prep recipes with it missing", {
 })
 
 test_that("printing", {
-  rec <- rec %>%
+  rec <- rec |>
     step_count(description, pattern = "(rock|stony)")
 
   expect_snapshot(print(rec))
@@ -268,20 +266,20 @@ test_that("bad args", {
   data(covers, package = "modeldata")
 
   expect_snapshot(
-    recipe(~description, covers) %>%
-      step_count(description, pattern = character(0)) %>%
+    recipe(~description, covers) |>
+      step_count(description, pattern = character(0)) |>
       prep(),
     error = TRUE
   )
   expect_snapshot(
-    recipe(~description, covers) %>%
-      step_count(description, pattern = "(rock|stony)", result = letters) %>%
+    recipe(~description, covers) |>
+      step_count(description, pattern = "(rock|stony)", result = letters) |>
       prep(),
     error = TRUE
   )
   expect_snapshot(
-    recipe(~description, covers) %>%
-      step_count(description, pattern = "(rock|stony)", normalize = "yes") %>%
+    recipe(~description, covers) |>
+      step_count(description, pattern = "(rock|stony)", normalize = "yes") |>
       prep(),
     error = TRUE
   )
@@ -289,8 +287,8 @@ test_that("bad args", {
 
 test_that("0 and 1 rows data work in bake method", {
   data <- covers
-  rec <- recipe(~., data) %>%
-    step_count(description, pattern = "(rock|stony)") %>%
+  rec <- recipe(~., data) |>
+    step_count(description, pattern = "(rock|stony)") |>
     prep()
 
   expect_identical(
