@@ -1,7 +1,7 @@
 test_that("Deprecation error", {
   expect_snapshot(
     error = TRUE,
-    recipe(~., data = mtcars) %>%
+    recipe(~., data = mtcars) |>
       step_modeimpute()
   )
 })
