@@ -1,6 +1,6 @@
 test_that("rethrows error correctly from implementation", {
   skip_if_not_installed("dials")
-  rec <- recipe(~., data = mtcars) %>%
+  rec <- recipe(~., data = mtcars) |>
     step_pca(all_predictors(), num_comp = hardhat::tune())
 
   local_mocked_bindings(
