@@ -9,81 +9,81 @@ iris_rec <- recipe(~., data = iris)
 
 test_that("basic usage - skip = FALSE", {
   rec <-
-    iris_rec %>%
-      step_filter(Sepal.Length > 4.5, Species == "setosa", skip = FALSE)
+    iris_rec |>
+    step_filter(Sepal.Length > 4.5, Species == "setosa", skip = FALSE)
 
-  prepped <- prep(rec, training = iris %>% slice(1:75))
+  prepped <- prep(rec, training = iris |> slice(1:75))
 
   dplyr_train <-
-    iris %>%
-      as_tibble() %>%
-      slice(1:75) %>%
-      dplyr::filter(Sepal.Length > 4.5, Species == "setosa")
+    iris |>
+    as_tibble() |>
+    slice(1:75) |>
+    dplyr::filter(Sepal.Length > 4.5, Species == "setosa")
 
   rec_train <- bake(prepped, new_data = NULL)
   expect_equal(dplyr_train, rec_train)
 
   dplyr_test <-
-    iris %>%
-      as_tibble() %>%
-      slice(76:150) %>%
-      dplyr::filter(Sepal.Length > 4.5, Species == "setosa")
+    iris |>
+    as_tibble() |>
+    slice(76:150) |>
+    dplyr::filter(Sepal.Length > 4.5, Species == "setosa")
   dplyr_test <- dplyr_test[, names(rec_train)]
 
-  rec_test <- bake(prepped, iris %>% slice(76:150))
+  rec_test <- bake(prepped, iris |> slice(76:150))
   expect_equal(dplyr_test, rec_test)
 })
 
 test_that("skip = FALSE", {
   rec <-
-    iris_rec %>%
-      step_filter(Sepal.Length > 4.5, Species == "setosa", skip = FALSE)
+    iris_rec |>
+    step_filter(Sepal.Length > 4.5, Species == "setosa", skip = FALSE)
 
-  prepped <- prep(rec, training = iris %>% slice(1:75))
+  prepped <- prep(rec, training = iris |> slice(1:75))
 
   dplyr_train <-
-    iris %>%
-      as_tibble() %>%
-      slice(1:75) %>%
-      dplyr::filter(Sepal.Length > 4.5, Species == "setosa")
+    iris |>
+    as_tibble() |>
+    slice(1:75) |>
+    dplyr::filter(Sepal.Length > 4.5, Species == "setosa")
 
   rec_train <- bake(prepped, new_data = NULL)
   expect_equal(dplyr_train, rec_train)
 
   dplyr_test <-
-    iris %>%
-      as_tibble() %>%
-      slice(76:150) %>%
-      dplyr::filter(Sepal.Length > 4.5, Species == "setosa")
-  rec_test <- bake(prepped, iris %>% slice(76:150))
+    iris |>
+    as_tibble() |>
+    slice(76:150) |>
+    dplyr::filter(Sepal.Length > 4.5, Species == "setosa")
+  rec_test <- bake(prepped, iris |> slice(76:150))
   expect_equal(dplyr_test, rec_test)
 })
 
 test_that("quasiquotation", {
   values <- c("versicolor", "virginica")
   rec_1 <-
-    iris_rec %>%
-      step_filter(Sepal.Length > 4.5, Species %in% values)
+    iris_rec |>
+    step_filter(Sepal.Length > 4.5, Species %in% values)
 
-  prepped_1 <- prep(rec_1, training = iris %>% slice(1:75))
+  prepped_1 <- prep(rec_1, training = iris |> slice(1:75))
 
   dplyr_train <-
-    iris %>%
-      as_tibble() %>%
-      slice(1:75) %>%
-      filter(Sepal.Length > 4.5, Species %in% values)
+    iris |>
+    as_tibble() |>
+    slice(1:75) |>
+    filter(Sepal.Length > 4.5, Species %in% values)
 
   rec_1_train <- bake(prepped_1, new_data = NULL)
   expect_equal(dplyr_train, rec_1_train)
 
   rec_2 <-
-    iris_rec %>%
-      step_filter(Sepal.Length > 4.5, Species %in% !!values)
+    iris_rec |>
+    step_filter(Sepal.Length > 4.5, Species %in% !!values)
 
-  prepped_2 <- prep(rec_2, training = iris %>% slice(1:75))
+  prepped_2 <- prep(rec_2, training = iris |> slice(1:75))
 
   expect_no_error(
-    prepped_2 <- prep(rec_2, training = iris %>% slice(1:75))
+    prepped_2 <- prep(rec_2, training = iris |> slice(1:75))
   )
   rec_2_train <- bake(prepped_2, new_data = NULL)
   expect_equal(dplyr_train, rec_2_train)
@@ -91,10 +91,10 @@ test_that("quasiquotation", {
 
 test_that("no input", {
   no_inputs <-
-    iris_rec %>%
-      step_filter() %>%
-      prep(training = iris) %>%
-      bake(new_data = NULL, composition = "data.frame")
+    iris_rec |>
+    step_filter() |>
+    prep(training = iris) |>
+    bake(new_data = NULL, composition = "data.frame")
   expect_equal(no_inputs, iris)
 })
 
@@ -102,8 +102,8 @@ test_that("doesn't destroy sparsity", {
   mtcars$vs <- sparsevctrs::as_sparse_integer(mtcars$vs)
   mtcars$am <- sparsevctrs::as_sparse_integer(mtcars$am)
 
-  rec <- recipe(~., mtcars) %>%
-    step_filter(vs == 0) %>%
+  rec <- recipe(~., mtcars) |>
+    step_filter(vs == 0) |>
     prep()
 
   expect_true(.recipes_preserve_sparsity(rec$steps[[1]]))
@@ -158,7 +158,7 @@ test_that("empty selection tidy method works", {
 })
 
 test_that("printing", {
-  rec <- iris_rec %>%
+  rec <- iris_rec |>
     step_filter(Sepal.Length > 4.5)
 
   expect_snapshot(print(rec))
@@ -167,8 +167,8 @@ test_that("printing", {
 
 test_that("0 and 1 rows data work in bake method", {
   data <- mtcars
-  rec <- recipe(~., data) %>%
-    step_filter(disp > 100) %>%
+  rec <- recipe(~., data) |>
+    step_filter(disp > 100) |>
     prep()
 
   expect_identical(
