@@ -12,7 +12,7 @@ rec <- recipe(X1 ~ ., data = tr_dat)
 test_that("correct kernel PCA values", {
   skip_if_not_installed("kernlab")
 
-  kpca_rec <- rec %>% step_kpca(X2, X3, X4, X5, X6, id = "")
+  kpca_rec <- rec |> step_kpca(X2, X3, X4, X5, X6, id = "")
 
   kpca_trained <- prep(kpca_rec, training = tr_dat, verbose = FALSE)
 
@@ -47,7 +47,7 @@ test_that("check_name() is used", {
   dat <- dplyr::as_tibble(tr_dat)
   dat$kPC1 <- dat$X1
 
-  rec <- recipe(~., data = dat) %>%
+  rec <- recipe(~., data = dat) |>
     step_kpca(X2, X3, X4, X5, X6)
 
   expect_snapshot(
@@ -59,8 +59,8 @@ test_that("check_name() is used", {
 test_that("No kPCA comps", {
   skip_if_not_installed("kernlab")
   suppressWarnings(
-    pca_extract <- rec %>%
-      step_kpca(X2, X3, X4, X5, X6, num_comp = 0, id = "") %>%
+    pca_extract <- rec |>
+      step_kpca(X2, X3, X4, X5, X6, num_comp = 0, id = "") |>
       prep()
   )
 
@@ -74,16 +74,16 @@ test_that("No kPCA comps", {
     tibble::tibble(terms = paste0("X", 2:6), id = "")
   )
   expect_snapshot(
-    pca_extract <- rec %>%
-      step_kpca(X2, X3, X4, X5, X6, num_comp = 0, id = "") %>%
+    pca_extract <- rec |>
+      step_kpca(X2, X3, X4, X5, X6, num_comp = 0, id = "") |>
       prep()
   )
   expect_snapshot(pca_extract)
 })
 
 test_that("Do nothing for num_comps = 0 and keep_original_cols = FALSE (#1152)", {
-  rec <- recipe(~., data = mtcars) %>%
-    step_kpca(all_predictors(), num_comp = 0, keep_original_cols = FALSE) %>%
+  rec <- recipe(~., data = mtcars) |>
+    step_kpca(all_predictors(), num_comp = 0, keep_original_cols = FALSE) |>
     prep()
 
   res <- bake(rec, new_data = NULL)
@@ -102,8 +102,8 @@ test_that("rethrows error correctly from implementation", {
   )
   expect_snapshot(
     error = TRUE,
-    recipe(~., data = mtcars) %>%
-      step_kpca(all_predictors()) %>%
+    recipe(~., data = mtcars) |>
+      step_kpca(all_predictors()) |>
       prep()
   )
 })
@@ -113,8 +113,8 @@ test_that("check_options() is used", {
 
   expect_snapshot(
     error = TRUE,
-    recipe(~mpg, data = mtcars) %>%
-      step_kpca(mpg, options = TRUE) %>%
+    recipe(~mpg, data = mtcars) |>
+      step_kpca(mpg, options = TRUE) |>
       prep()
   )
 })
@@ -124,9 +124,9 @@ test_that("check_options() is used", {
 test_that("bake method errors when needed non-standard role columns are missing", {
   skip_if_not_installed("kernlab")
 
-  kpca_rec <- rec %>%
-    step_kpca(X2, X3, X4, X5, X6) %>%
-    update_role(X2, X3, X4, X5, X6, new_role = "potato") %>%
+  kpca_rec <- rec |>
+    step_kpca(X2, X3, X4, X5, X6) |>
+    update_role(X2, X3, X4, X5, X6, new_role = "potato") |>
     update_role_requirements(role = "potato", bake = FALSE)
 
   kpca_trained <- prep(kpca_rec, training = tr_dat, verbose = FALSE)
@@ -175,7 +175,7 @@ test_that("keep_original_cols works", {
   skip_if_not_installed("kernlab")
   new_names <- paste0("kPC", 1:5)
 
-  rec <- recipe(~mpg, mtcars) %>%
+  rec <- recipe(~mpg, mtcars) |>
     step_kpca(all_predictors(), keep_original_cols = FALSE)
 
   rec <- prep(rec)
@@ -186,7 +186,7 @@ test_that("keep_original_cols works", {
     new_names
   )
 
-  rec <- recipe(~mpg, mtcars) %>%
+  rec <- recipe(~mpg, mtcars) |>
     step_kpca(all_predictors(), keep_original_cols = TRUE)
 
   rec <- prep(rec)
@@ -200,7 +200,7 @@ test_that("keep_original_cols works", {
 
 test_that("keep_original_cols - can prep recipes with it missing", {
   skip_if_not_installed("kernlab")
-  rec <- recipe(~mpg, mtcars) %>%
+  rec <- recipe(~mpg, mtcars) |>
     step_kpca(all_predictors())
 
   rec$steps[[1]]$keep_original_cols <- NULL
@@ -217,7 +217,7 @@ test_that("keep_original_cols - can prep recipes with it missing", {
 test_that("printing", {
   skip_if_not_installed("kernlab")
 
-  rec <- recipe(X1 ~ ., data = tr_dat) %>%
+  rec <- recipe(X1 ~ ., data = tr_dat) |>
     step_kpca(X2, X3, X4, X5, X6)
 
   expect_snapshot(print(rec))
@@ -228,14 +228,14 @@ test_that("bad args", {
   skip_if_not_installed("kernlab")
 
   expect_snapshot(
-    recipe(~., data = tr_dat) %>%
-      step_kpca(all_numeric_predictors(), num_comp = -1) %>%
+    recipe(~., data = tr_dat) |>
+      step_kpca(all_numeric_predictors(), num_comp = -1) |>
       prep(),
     error = TRUE
   )
   expect_snapshot(
-    recipe(~., data = tr_dat) %>%
-      step_kpca(all_numeric_predictors(), prefix = 1) %>%
+    recipe(~., data = tr_dat) |>
+      step_kpca(all_numeric_predictors(), prefix = 1) |>
       prep(),
     error = TRUE
   )
@@ -245,8 +245,8 @@ test_that("0 and 1 rows data work in bake method", {
   skip_if_not_installed("kernlab")
 
   data <- mtcars
-  rec <- recipe(~., data) %>%
-    step_kpca(all_numeric_predictors()) %>%
+  rec <- recipe(~., data) |>
+    step_kpca(all_numeric_predictors()) |>
     prep()
 
   expect_identical(
