@@ -5,65 +5,65 @@ iris_rec <- recipe(~., data = iris)
 
 test_that("basic usage", {
   rec <-
-    iris_rec %>%
-      step_mutate(
-        dbl_width = Sepal.Width * 2,
-        half_length = Sepal.Length / 2
-      )
+    iris_rec |>
+    step_mutate(
+      dbl_width = Sepal.Width * 2,
+      half_length = Sepal.Length / 2
+    )
 
-  prepped <- prep(rec, training = iris %>% slice(1:75))
+  prepped <- prep(rec, training = iris |> slice(1:75))
 
   dplyr_train <-
-    iris %>%
-      as_tibble() %>%
-      slice(1:75) %>%
-      mutate(
-        dbl_width = Sepal.Width * 2,
-        half_length = Sepal.Length / 2
-      )
+    iris |>
+    as_tibble() |>
+    slice(1:75) |>
+    mutate(
+      dbl_width = Sepal.Width * 2,
+      half_length = Sepal.Length / 2
+    )
 
   rec_train <- bake(prepped, new_data = NULL)
   expect_equal(dplyr_train, rec_train)
 
   dplyr_test <-
-    iris %>%
-      as_tibble() %>%
-      slice(76:150) %>%
-      mutate(
-        dbl_width = Sepal.Width * 2,
-        half_length = Sepal.Length / 2
-      )
-  rec_test <- bake(prepped, iris %>% slice(76:150))
+    iris |>
+    as_tibble() |>
+    slice(76:150) |>
+    mutate(
+      dbl_width = Sepal.Width * 2,
+      half_length = Sepal.Length / 2
+    )
+  rec_test <- bake(prepped, iris |> slice(76:150))
   expect_equal(dplyr_test, rec_test)
 })
 
 test_that("quasiquotation", {
   const <- 9.077
   rec_1 <-
-    iris_rec %>%
-      step_mutate(new_var = Sepal.Width * const)
+    iris_rec |>
+    step_mutate(new_var = Sepal.Width * const)
 
-  prepped_1 <- prep(rec_1, training = iris %>% slice(1:75))
+  prepped_1 <- prep(rec_1, training = iris |> slice(1:75))
 
   dplyr_train <-
-    iris %>%
-      as_tibble() %>%
-      slice(1:75) %>%
-      mutate(new_var = Sepal.Width * const)
+    iris |>
+    as_tibble() |>
+    slice(1:75) |>
+    mutate(new_var = Sepal.Width * const)
 
   rec_1_train <- bake(prepped_1, new_data = NULL)
   expect_equal(dplyr_train, rec_1_train)
 
   rec_2 <-
-    iris_rec %>%
-      step_mutate(new_var = Sepal.Width * !!const)
+    iris_rec |>
+    step_mutate(new_var = Sepal.Width * !!const)
 
-  prepped_2 <- prep(rec_2, training = iris %>% slice(1:75))
+  prepped_2 <- prep(rec_2, training = iris |> slice(1:75))
 
   rm(const)
-  expect_snapshot(error = TRUE, prep(rec_1, training = iris %>% slice(1:75)))
+  expect_snapshot(error = TRUE, prep(rec_1, training = iris |> slice(1:75)))
   expect_no_error(
-    prepped_2 <- prep(rec_2, training = iris %>% slice(1:75))
+    prepped_2 <- prep(rec_2, training = iris |> slice(1:75))
   )
   rec_2_train <- bake(prepped_2, new_data = NULL)
   expect_equal(dplyr_train, rec_2_train)
@@ -78,7 +78,7 @@ test_that("can use unnamed expressions like `across()` (#759)", {
     z = c(TRUE, FALSE)
   )
 
-  rec <- recipe(~., df) %>%
+  rec <- recipe(~., df) |>
     step_mutate(across(where(is.logical), as.integer))
 
   rec <- prep(rec, df)
@@ -106,7 +106,7 @@ test_that("tidying allows for named and unnamed expressions", {
 })
 
 test_that("required_pkgs.step_mutate() works", {
-  rec <- recipe(~., data = mtcars) %>%
+  rec <- recipe(~., data = mtcars) |>
     step_mutate(new = 2)
 
   rec_pred <- prep(rec)
@@ -114,7 +114,7 @@ test_that("required_pkgs.step_mutate() works", {
   expect_equal(required_pkgs(rec), "recipes")
   expect_equal(required_pkgs(rec_pred), "recipes")
 
-  rec <- recipe(~., data = mtcars) %>%
+  rec <- recipe(~., data = mtcars) |>
     step_mutate(new = 2, .pkgs = "stats")
 
   rec_pred <- prep(rec)
@@ -123,13 +123,13 @@ test_that("required_pkgs.step_mutate() works", {
   expect_equal(required_pkgs(rec_pred), c("recipes", "stats"))
 
   expect_snapshot(
-    recipe(~., data = mtcars) %>%
+    recipe(~., data = mtcars) |>
       step_mutate(new = 2, .pkgs = "not-a-package")
   )
 })
 
 test_that("step_mutate() .pkgs argument is backwards compatible", {
-  rec <- recipe(~., data = mtcars) %>%
+  rec <- recipe(~., data = mtcars) |>
     step_mutate(new = 2)
 
   rec$steps[[1]]$.pkgs <- NULL
@@ -139,7 +139,7 @@ test_that("step_mutate() .pkgs argument is backwards compatible", {
   expect_equal(required_pkgs(rec), "recipes")
   expect_equal(required_pkgs(rec_pred), "recipes")
 
-  rec <- recipe(~., data = mtcars) %>%
+  rec <- recipe(~., data = mtcars) |>
     step_mutate(new = 2)
 
   rec_pred <- prep(rec)
@@ -184,7 +184,7 @@ test_that("empty selection prep/bake is a no-op", {
 })
 
 test_that("printing", {
-  rec <- recipe(~., data = iris) %>%
+  rec <- recipe(~., data = iris) |>
     step_mutate(x = 5)
 
   expect_snapshot(print(rec))
@@ -193,8 +193,8 @@ test_that("printing", {
 
 test_that("0 and 1 rows data work in bake method", {
   data <- mtcars
-  rec <- recipe(~., data) %>%
-    step_mutate(disp = disp / 4) %>%
+  rec <- recipe(~., data) |>
+    step_mutate(disp = disp / 4) |>
     prep()
 
   expect_identical(
