@@ -4,48 +4,48 @@ library(recipes)
 df <- tibble(val1 = -10:10, val2 = factor(LETTERS[1:21]))
 
 test_that("default relu settings", {
-  baked <- recipe(~., data = df) %>%
-    step_relu(val1) %>%
-    prep(df, verbose = FALSE) %>%
+  baked <- recipe(~., data = df) |>
+    step_relu(val1) |>
+    prep(df, verbose = FALSE) |>
     bake(df)
 
-  expected_baked <- df %>%
+  expected_baked <- df |>
     dplyr::mutate(right_relu_val1 = pmax(rep(0, length(val1)), val1))
 
   expect_equal(baked, expected_baked)
 })
 
 test_that("shifted and reversed relu", {
-  baked <- recipe(~., data = df) %>%
-    step_relu(val1, shift = 5, reverse = TRUE) %>%
-    prep(df, verbose = FALSE) %>%
+  baked <- recipe(~., data = df) |>
+    step_relu(val1, shift = 5, reverse = TRUE) |>
+    prep(df, verbose = FALSE) |>
     bake(df)
 
-  expected_baked <- df %>%
+  expected_baked <- df |>
     dplyr::mutate(left_relu_val1 = pmax(rep(0, length(val1)), -(val1 - 5)))
 
   expect_equal(baked, expected_baked)
 })
 
 test_that("reversed softplus", {
-  baked <- recipe(~., data = df) %>%
-    step_relu(val1, smooth = TRUE, reverse = TRUE) %>%
-    prep(df, verbose = FALSE) %>%
+  baked <- recipe(~., data = df) |>
+    step_relu(val1, smooth = TRUE, reverse = TRUE) |>
+    prep(df, verbose = FALSE) |>
     bake(df)
 
-  expected_baked <- df %>%
+  expected_baked <- df |>
     dplyr::mutate(left_relu_val1 = log1p(exp(-val1)))
 
   expect_equal(baked, expected_baked)
 })
 
 test_that("shifted and prefixed softplus", {
-  baked <- recipe(~., data = df) %>%
-    step_relu(val1, shift = 5, smooth = TRUE, prefix = "sp_") %>%
-    prep(df, verbose = FALSE) %>%
+  baked <- recipe(~., data = df) |>
+    step_relu(val1, shift = 5, smooth = TRUE, prefix = "sp_") |>
+    prep(df, verbose = FALSE) |>
     bake(df)
 
-  expected_baked <- df %>%
+  expected_baked <- df |>
     dplyr::mutate(sp_val1 = log1p(exp(val1 - 5)))
 
   expect_equal(baked, expected_baked)
@@ -53,7 +53,7 @@ test_that("shifted and prefixed softplus", {
 
 test_that("works with all_predictors() selector", {
   expect_silent({
-    rec <- recipe(Species ~ ., data = iris) %>%
+    rec <- recipe(Species ~ ., data = iris) |>
       step_relu(all_predictors())
   })
 
@@ -63,29 +63,29 @@ test_that("works with all_predictors() selector", {
 test_that("input checking", {
   expect_snapshot(
     error = TRUE,
-    recipe(~., data = df) %>%
-      step_relu(val1, shift = TRUE) %>% # wrong argument type to shift
+    recipe(~., data = df) |>
+      step_relu(val1, shift = TRUE) |> # wrong argument type to shift
       prep(df, verbose = FALSE)
   )
 
   expect_snapshot(
     error = TRUE,
-    recipe(~., data = df) %>%
-      step_relu(val1, reverse = 3) %>% # wrong argument type to reverse
+    recipe(~., data = df) |>
+      step_relu(val1, reverse = 3) |> # wrong argument type to reverse
       prep(df, verbose = FALSE)
   )
 
   expect_snapshot(
     error = TRUE,
-    recipe(~., data = df) %>%
-      step_relu(val1, smooth = "cat") %>% # wrong argument type to smooth
+    recipe(~., data = df) |>
+      step_relu(val1, smooth = "cat") |> # wrong argument type to smooth
       prep(df, verbose = FALSE)
   )
 
   expect_snapshot(
     error = TRUE,
-    recipe(~., data = df) %>%
-      step_relu(val2) %>% # apply to non-numeric column
+    recipe(~., data = df) |>
+      step_relu(val2) |> # apply to non-numeric column
       prep(df, verbose = FALSE)
   )
 })
@@ -93,10 +93,10 @@ test_that("input checking", {
 # Infrastructure ---------------------------------------------------------------
 
 test_that("bake method errors when needed non-standard role columns are missing", {
-  rec <- recipe(~., data = df) %>%
-    step_relu(val1) %>%
-    update_role(val1, new_role = "potato") %>%
-    update_role_requirements("potato", bake = FALSE) %>%
+  rec <- recipe(~., data = df) |>
+    step_relu(val1) |>
+    update_role(val1, new_role = "potato") |>
+    update_role_requirements("potato", bake = FALSE) |>
     prep(df, verbose = FALSE)
 
   expect_snapshot(error = TRUE, bake(rec, df[, 2, drop = FALSE]))
@@ -145,7 +145,7 @@ test_that("empty selection tidy method works", {
 })
 
 test_that("printing", {
-  rec <- recipe(~., data = mtcars) %>%
+  rec <- recipe(~., data = mtcars) |>
     step_relu(disp)
 
   expect_snapshot(print(rec))
@@ -154,8 +154,8 @@ test_that("printing", {
 
 test_that("0 and 1 rows data work in bake method", {
   data <- mtcars
-  rec <- recipe(~., data) %>%
-    step_relu(disp, mpg) %>%
+  rec <- recipe(~., data) |>
+    step_relu(disp, mpg) |>
     prep()
 
   expect_identical(
