@@ -2,9 +2,9 @@ library(recipes)
 library(testthat)
 
 test_that("simple skip", {
-  rec_1 <- recipe(Sepal.Length ~ ., data = iris) %>%
-    step_log(Sepal.Length, skip = TRUE) %>%
-    step_dummy(Species) %>%
+  rec_1 <- recipe(Sepal.Length ~ ., data = iris) |>
+    step_log(Sepal.Length, skip = TRUE) |>
+    step_dummy(Species) |>
     step_center(all_predictors())
 
   prepped_1 <- prep(rec_1, training = iris)
@@ -88,9 +88,9 @@ test_that("check existing steps for `skip` arg", {
 
 test_that("skips for steps that remove columns (#239)", {
   simple_ex <-
-    recipe(Species ~ ., data = iris) %>%
-      step_interact(terms = ~Sepal.Length:Sepal.Width) %>%
-      step_rm(Sepal.Length, skip = TRUE)
+    recipe(Species ~ ., data = iris) |>
+    step_interact(terms = ~ Sepal.Length:Sepal.Width) |>
+    step_rm(Sepal.Length, skip = TRUE)
 
   prep_simple <- prep(simple_ex, iris)
   simple_juiced <- juice(prep_simple)
@@ -123,12 +123,12 @@ test_that("skips for steps that remove columns (#239)", {
   )
 
   complex_ex <-
-    recipe(Species ~ ., data = iris) %>%
-      step_interact(terms = ~Sepal.Length:Sepal.Width) %>%
-      step_rm(Sepal.Length) %>%
-      step_pca(contains("Sepal")) %>%
-      step_rm(PC1, skip = TRUE) %>%
-      prep()
+    recipe(Species ~ ., data = iris) |>
+    step_interact(terms = ~ Sepal.Length:Sepal.Width) |>
+    step_rm(Sepal.Length) |>
+    step_pca(contains("Sepal")) |>
+    step_rm(PC1, skip = TRUE) |>
+    prep()
 
   complex_juiced <- juice(complex_ex)
   complex_baked <- bake(complex_ex, new_data = iris)
@@ -143,16 +143,16 @@ test_that("skips for steps that remove columns (#239)", {
   )
 
   iris_dups <-
-    iris %>%
-      mutate(
-        dup_1 = Sepal.Width,
-        dup_2 = Sepal.Width
-      )
+    iris |>
+    mutate(
+      dup_1 = Sepal.Width,
+      dup_2 = Sepal.Width
+    )
 
   corr_example <-
-    recipe(Species ~ ., data = iris_dups) %>%
-      step_corr(all_predictors(), skip = TRUE) %>%
-      prep()
+    recipe(Species ~ ., data = iris_dups) |>
+    step_corr(all_predictors(), skip = TRUE) |>
+    prep()
 
   corr_juiced <- juice(corr_example)
   corr_baked <- bake(corr_example, new_data = iris_dups)
