@@ -18,7 +18,7 @@ test_that("correct basis functions", {
     data = biomass_tr
   )
 
-  with_ns <- rec %>%
+  with_ns <- rec |>
     step_spline_b(carbon, hydrogen, deg_free = 5)
 
   with_ns <- prep(with_ns, training = biomass_tr, verbose = FALSE)
@@ -86,28 +86,28 @@ test_that("errors if degree > deg_free (#1170)", {
   skip_if_not_installed("splines2")
 
   expect_no_error(
-    recipe(~., data = mtcars) %>%
-      step_spline_b(mpg, degree = 2, deg_free = 3, complete_set = TRUE) %>%
+    recipe(~., data = mtcars) |>
+      step_spline_b(mpg, degree = 2, deg_free = 3, complete_set = TRUE) |>
       prep()
   )
 
   expect_no_error(
-    recipe(~., data = mtcars) %>%
-      step_spline_b(mpg, degree = 3, deg_free = 3, complete_set = FALSE) %>%
+    recipe(~., data = mtcars) |>
+      step_spline_b(mpg, degree = 3, deg_free = 3, complete_set = FALSE) |>
       prep()
   )
 
   expect_snapshot(
     error = TRUE,
-    recipe(~., data = mtcars) %>%
-      step_spline_b(mpg, degree = 3, deg_free = 3, complete_set = TRUE) %>%
+    recipe(~., data = mtcars) |>
+      step_spline_b(mpg, degree = 3, deg_free = 3, complete_set = TRUE) |>
       prep()
   )
 
   expect_snapshot(
     error = TRUE,
-    recipe(~., data = mtcars) %>%
-      step_spline_b(mpg, degree = 4, deg_free = 3, complete_set = FALSE) %>%
+    recipe(~., data = mtcars) |>
+      step_spline_b(mpg, degree = 4, deg_free = 3, complete_set = FALSE) |>
       prep()
   )
 })
@@ -116,7 +116,7 @@ test_that("check_name() is used", {
   dat <- mtcars
   dat$mpg_01 <- dat$mpg
 
-  rec <- recipe(~., data = dat) %>%
+  rec <- recipe(~., data = dat) |>
     step_spline_b(mpg)
 
   expect_snapshot(
@@ -135,8 +135,8 @@ test_that("tunable", {
   )
 
   rec <-
-    recipe(~., data = iris) %>%
-      step_spline_b(all_predictors())
+    recipe(~., data = iris) |>
+    step_spline_b(all_predictors())
   rec_param <- tunable.step_spline_b(rec$steps[[1]])
   expect_equal(rec_param$name, c("deg_free", "degree"))
   expect_true(all(rec_param$source == "recipe"))
@@ -149,8 +149,8 @@ test_that("tunable", {
 })
 
 test_that("works when baked with 1 row", {
-  rec <- recipe(mpg ~ ., data = mtcars) %>%
-    step_spline_b(disp) %>%
+  rec <- recipe(mpg ~ ., data = mtcars) |>
+    step_spline_b(disp) |>
     prep()
 
   expect_no_error(
@@ -166,8 +166,8 @@ test_that("errors with zero variance predictors (#1455)", {
 
   expect_snapshot(
     error = TRUE,
-    recipe(mpg ~ ., data = mtcars) %>%
-      step_spline_b(all_numeric_predictors()) %>%
+    recipe(mpg ~ ., data = mtcars) |>
+      step_spline_b(all_numeric_predictors()) |>
       prep()
   )
 })
@@ -177,8 +177,8 @@ test_that("check_options() is used", {
 
   expect_snapshot(
     error = TRUE,
-    recipe(~mpg, data = mtcars) %>%
-      step_spline_b(mpg, options = TRUE) %>%
+    recipe(~mpg, data = mtcars) |>
+      step_spline_b(mpg, options = TRUE) |>
       prep()
   )
 })
@@ -186,9 +186,9 @@ test_that("check_options() is used", {
 # Infrastructure ---------------------------------------------------------------
 
 test_that("bake method errors when needed non-standard role columns are missing", {
-  rec <- recipe(mtcars) %>%
-    step_spline_b(disp) %>%
-    update_role(disp, new_role = "potato") %>%
+  rec <- recipe(mtcars) |>
+    step_spline_b(disp) |>
+    update_role(disp, new_role = "potato") |>
     update_role_requirements(role = "potato", bake = FALSE)
 
   rec_trained <- prep(rec, training = mtcars)
@@ -236,7 +236,7 @@ test_that("empty selection tidy method works", {
 test_that("keep_original_cols works", {
   new_names <- paste0("mpg_", formatC(1:10, width = 2, flag = "0"))
 
-  rec <- recipe(~mpg, mtcars) %>%
+  rec <- recipe(~mpg, mtcars) |>
     step_spline_b(all_predictors(), keep_original_cols = FALSE)
 
   rec <- prep(rec)
@@ -247,7 +247,7 @@ test_that("keep_original_cols works", {
     new_names
   )
 
-  rec <- recipe(~mpg, mtcars) %>%
+  rec <- recipe(~mpg, mtcars) |>
     step_spline_b(all_predictors(), keep_original_cols = TRUE)
 
   rec <- prep(rec)
@@ -269,7 +269,7 @@ test_that("printing", {
   rec <- recipe(
     HHV ~ carbon + hydrogen + oxygen + nitrogen + sulfur,
     data = biomass
-  ) %>%
+  ) |>
     step_spline_b(carbon, hydrogen)
 
   expect_snapshot(print(rec))
@@ -278,7 +278,7 @@ test_that("printing", {
 
 test_that("tunable is setup to work with extract_parameter_set_dials", {
   skip_if_not_installed("dials")
-  rec <- recipe(~., data = mtcars) %>%
+  rec <- recipe(~., data = mtcars) |>
     step_spline_b(
       all_predictors(),
       deg_free = hardhat::tune(),
@@ -295,20 +295,20 @@ test_that("bad args", {
   skip_if_not_installed("splines2")
 
   expect_snapshot(
-    recipe(mpg ~ ., data = mtcars) %>%
-      step_spline_b(disp, degree = -1) %>%
+    recipe(mpg ~ ., data = mtcars) |>
+      step_spline_b(disp, degree = -1) |>
       prep(),
     error = TRUE
   )
   expect_snapshot(
-    recipe(mpg ~ ., data = mtcars) %>%
-      step_spline_b(disp, deg_free = "a") %>%
+    recipe(mpg ~ ., data = mtcars) |>
+      step_spline_b(disp, deg_free = "a") |>
       prep(),
     error = TRUE
   )
   expect_snapshot(
-    recipe(mpg ~ ., data = mtcars) %>%
-      step_spline_b(disp, complete_set = 1) %>%
+    recipe(mpg ~ ., data = mtcars) |>
+      step_spline_b(disp, complete_set = 1) |>
       prep(),
     error = TRUE
   )
@@ -318,8 +318,8 @@ test_that("0 and 1 rows data work in bake method", {
   skip_if_not_installed("splines2")
 
   data <- mtcars
-  rec <- recipe(~., data) %>%
-    step_spline_b(mpg, disp) %>%
+  rec <- recipe(~., data) |>
+    step_spline_b(mpg, disp) |>
     prep()
 
   expect_identical(
